==> hashedin-logan-0.1.tar.gz: hashedin-logan-0.1/logan/eventlogger.py <==
import json
import ssl
import requests
from logan import exceptions
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.poolmanager import PoolManager


class LoganAPI(object):
    
    base_url = "https://logan.hashedin.com/api/v0"
    events_url = "%s/events" % base_url
    def __init__(self, access_token, base_url=None, events_url=None, conn_timeout=4, read_timeout=5):
        self.conn_timeout = conn_timeout
        self.read_timeout = read_timeout
        self.access_token = access_token
        if base_url:
            self.base_url = base_url
        if events_url:
            self.events_url = events_url
        self.session = self._create_session()

    def _create_session(self):

        """ Build a session that uses KeenAdapter for SSL """

        s = requests.Session()
        a = requests.adapters.HTTPAdapter(pool_connections=10, 
                                            pool_maxsize=10,
                                            pool_block=False
                                            )
        s.mount('https://', a)
        s.mount('http://', a)
        return s


    def post_event(self, event):
        headers = {"Content-Type": "application/json", "Authorization": self.access_token}
        payload = json.dumps(event)
        response = self.session.post(self.events_url, data=payload, headers=headers, timeout=(self.conn_timeout, self.read_timeout))
        if response.status_code != 201:
            error = response.json()
            raise exceptions.LoganError(error)

==> hashedin-logan-0.2.tar.gz: hashedin-logan-0.2/logan/eventlogger.py <==
import json
import ssl
import requests
from logan import exceptions
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.poolmanager import PoolManager


class LoganAPI(object):
    
    base_url = "http://logan.labs.hashedin.com/api/v0"
    events_url = "%s/events" % base_url
    def __init__(self, access_token, base_url=None, events_url=None, conn_timeout=4, read_timeout=5):
        self.conn_timeout = conn_timeout
        self.read_timeout = read_timeout
        self.access_token = access_token
        if base_url:
            self.base_url = base_url
        if events_url:
            self.events_url = events_url
        self.session = self._create_session()

    def _create_session(self):

        """ Build a session that uses KeenAdapter for SSL """

        s = requests.Session()
        a = requests.adapters.HTTPAdapter(pool_connections=10, 
                                            pool_maxsize=10,
                                            pool_block=False
                                            )
        s.mount('https://', a)
        s.mount('http://', a)
        return s



    def post_event(self, event_name, event=None):
        if not event:
            event = {}
        event['name'] = event_name
        return self._post_event_internal(event)


    def _post_event_internal(self, event):
        headers = {"Content-Type": "application/json", "Authorization": self.access_token}
        payload = json.dumps(event)
        response = self.session.post(self.events_url, data=payload, headers=headers, timeout=(self.conn_timeout, self.read_timeout))
        if response.status_code != 201:
            error = response.json()
            raise exceptions.LoganError(error)
